#
# spec file for package bibletime
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012-2014 Lars Vogdt
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           bibletime
Version:        2.10.1
Release:        5.19
Summary:        An easy to use Bible study tool
License:        GPL-2.0+
Group:          Productivity/Scientific/Other
Url:            http://www.bibletime.info/
Source0:        %name-%version.tar.xz
Source2:        bibletime-rpmlintrc
BuildRequires:  boost-devel
BuildRequires:  cmake
BuildRequires:  curl-devel
BuildRequires:  libqt4-devel
BuildRequires:  sword-devel >= 1.7
Provides:       %{name}-i18n = %version
Obsoletes:      %{name}-devel < 1.7
Obsoletes:      %{name}-i18n < 1.7
Provides:       %{name}-devel = %version
Provides:       sword-frontend
#
# openSUSE
#
%if 0%{?suse_version}
BuildRequires:  clucene-core-devel
BuildRequires:  fdupes
BuildRequires:  libQtWebKit-devel
BuildRequires:  pkg-config
BuildRequires:  update-desktop-files
Recommends:     sword-bible
Recommends:     sword-commentary
%endif
#
# Fedora
#
%if 0%{?fedora_version}
BuildRequires:  clucene-core-devel
BuildRequires:  desktop-file-utils
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
%if 0%{?fedora_version} > 11
#BuildRequires:  webkitkde-devel
BuildRequires:  qt-webkit-devel
%else
BuildRequires:  WebKit-qt-devel
%endif
%endif
#
# Mandriva
#
%if 0%{?mandriva_version}
BuildRequires:  desktop-file-utils
BuildRequires:  libclucene-devel
BuildRequires:  pkgconfig
%endif

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define         kdeprefix %{_prefix}

%description
BibleTime is a completely free Bible study program.

The software uses the SWORD programming library to work with over 200 free
Bible texts, commentaries, dictionaries and books provided by the Crosswire
Bible Society.

BibleTime provides easy handling of digitalized texts (Bibles, commentaries and
lexicons) and powerful features to work with these texts (search in texts,
write own notes, save, print etc.).

%prep
%setup -q

%build
mkdir build
pushd build >/dev/null
cmake -DCMAKE_BUILD_TYPE=Release -DCMAKE_INSTALL_PREFIX="%{_prefix}" ../
%{__make} %{?_smp_mflags}
popd >/dev/null

%install 
pushd build >/dev/null
make install DESTDIR="%{buildroot}"
popd >/dev/null
# fix language pathnames
test -d %{buildroot}%kdeprefix/share/locale/pt_br && mv %{buildroot}%kdeprefix/share/locale/pt_br %{buildroot}%kdeprefix/share/locale/pt_BR
test -d %{buildroot}%kdeprefix/share/doc/HTML/pt-br && mv %{buildroot}%kdeprefix/share/doc/HTML/pt-br %{buildroot}%kdeprefix/share/doc/HTML/pt_BR
# install manpages
install -Dm644 docs/manpages/bibletime.1 %{buildroot}%{_mandir}/man1/bibletime.1
install -Dm644 docs/manpages/bibletime.de.1 %{buildroot}%{_mandir}/de/man1/bibletime.1
# move the icon to a valid place (/usr/share/icons is not valid... it has to be in a theme; hicolor as the usual falback)
# this is only a link pointing out of the icons
rm %{buildroot}%{_datadir}/icons/%{name}.svg
mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps
mv %{buildroot}%{_datadir}/%{name}/icons/%{name}.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
# then link back the icon into the app directory
ln -sf %{_datadir}/icons/hicolor/scalable/apps/%{name}.svg %{buildroot}%{_datadir}/%{name}/icons/%{name}.svg
%if 0%{?suse_version}
	%fdupes -s %{buildroot}
	sed -i "s|bibletime/handbook/index.html|bibletime/handbook/en/index.html|" %{buildroot}%{_datadir}/applications/%{name}.desktop
	%suse_update_desktop_file -r %{name} Education Teaching
%endif
#
%if 0%{?fedora_version} || 0%{?mandriva_version}
install -Dm644 ./cmake/platforms/linux/bibletime.desktop.cmake %{buildroot}%{_datadir}/applications/bibletime.desktop
%endif

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc %{_mandir}/man1/bibletime.1*
%doc %{_mandir}/de/man1/bibletime.1*
%dir %kdeprefix/share/bibletime
%kdeprefix/bin/*
%kdeprefix/share/icons/*
%kdeprefix/share/applications/bibletime.desktop
%kdeprefix/share/bibletime/*

%changelog
* Wed Apr  8 2015 dimstar@opensuse.org
- No longer package bibletime.xpm: there are perfectly good icons
  inside the tarball (even in scalable svg format).
- Fix the installation location of the icon: ensure the real file
  is located in /usr/share/icons/[..].
* Mon Jul  7 2014 lars@linux-schulserver.de
- udpate to 2.10.1:
  * Implemented support for localized module config entries.
  * Fixed an OSIS rendering bug.
  * Fixed some HTML rendering issues.
  * Fixed key chooser bug in book windows.
  * Fixed double loading of some settings.
  * Fixed Text Filter settings not being saved.
  * Various install manager bug fixes.
  * Various other minor fixes and optimizations.
* Tue Dec 31 2013 lars@linux-schulserver.de
- update to 2.10.0:
  + Enhancements:
  ++ Uses Sword library version 1.7.
  ++ Added Find context menu for search within each window. Matching
    words are highlighted and navigated using next or previous buttons.
  ++ Added support for HTTP, HTTPS, SFTP transports in BibleTime.
  ++ Implemented saving of font family and size in HTML commentary editor.
  + Bugs fixed:
  ++ Fixed problem where certain alternate versification bibles did not
    display old testament.
  ++ Fixed Windows Control Panel version was to be correct.
  ++ Fixed search analysis save dialog filters.
  ++ Fixed search analysis save asking for overwrite confirmation twice.
  ++ Optimized and enhanced search analysis to output proper XHTML.
  ++ Fixed widget ending up disabled after removing install source.
  ++ Mag Window uses current module if no default cross reference is set.
  ++ Fixed a bug in the HTML commentary editor which resulted in text
    formatting from the cursor to be applied to the whole selection.
  ++ Allow comboxboxes on config dialog desk page to resize.
  ++ Fixed some lexicons never working.
  ++ Fixed high stack memory usage on indexing.
  ++ Fixed unexpected exception with encrypted modules.
  ++ Fixed application freeze during installation of works.
* Tue Jun  4 2013 lars@linux-schulserver.de
- update to 2.9.2:
  + Fixed settings dialog tab contents not being translated
  + Fix crash when closing window with tab
  + Fix bug 14 - Headers displayed as plain text in some modules
  + Fix problem with text not displaying when using QtWebKit 2.3
  + added changes needed for Qt5
  + Fix multi-arch path issue in FindCLucene.cmake
- removed fix-movetoanchor-for-qt5.patch (upstream)
* Fri May  3 2013 hrvoje.senjan@gmail.com
- Added fix-movetoanchor-for-qt5.patch, fixes non visible text when
  used with libQtWebkit 2.3
* Sat Dec 15 2012 lars@linux-schulserver.de
- specfile cleanup
- fix license to be in SPDX format
- fix build on Fedora and Mandriva
* Fri Dec 30 2011 lars@linux-schulserver.de
- update to 2.9.1:
  + Fixed Portuguese translation not being included.
  + Updated British translation.
  + Updated handbooks.
- Notable changes since the 2.8 series:
  + Add close buttons to tabbed works windows.
  + Hovering over works in the bookshelf views shows tooltips.
  + Hovering over works in the bookshelf dock shows info in the mag view.
  + Add toolbar icons to toggle visibility of docking windows.
  + Switch off footnotes in display options.
  + Bible windows can have parallel commentaries.
* Sat Sep 10 2011 lars@linux-schulserver.de
- update to 2.8.2:
  + Fixed bookshelf manager install page taking long to open.
  + Fix restoring from fullscreen to a maximized window.
  + Fixed Personal Commentary texts being saved to wrong
    references.
  + Fixed an assert-crash caused by not catching indexing failures
    properly.
* Sat Jan 29 2011 lars@linux-schulserver.de
- update to 2.8.1:
  + Fixed a bug which caused many works to be incorrectly categorized
  + Fixed a Bookshelf Manager crash caused by installation sources
    which provide invalid data
* Sat Dec 18 2010 lars@linux-schulserver.de
- update to 2.8.0:
  + Redesigned and refactored the bookshelf manager
  + Implemented the Tip Of The Day dialog
  + Made BibleTime handle missing default template gracefully
  + Made the "Remove modules" confirmation dialog a bit prettier
  + Fixed a crash triggered by an assertion in legacy code
  + Fix main window toolbar key changer to save a modified entry
    in Personal Commentary
* Thu Oct 21 2010 lars@linux-schulserver.de
- update to 2.7.3:
  + Backported "Fixed invalid bibletimerc creation; removed unused
    CResMgr::init_tr()." by Jaak Ristioja
  + Backported "Fix crash opening first window in manual arrangement
    mode." by Gary Holmlund.
  + Backported "Fixed a bug that caused some users home directories
    to be deleted" by Jaak Ristioja.
  + Backported "Save the "grouping" setting of the Bookshelf"
    by Gary Holmlund.
* Fri Jul  9 2010 lars@linux-schulserver.de
- update to 2.7:
  + Fix bug #2969498 : Resize bug in magnification area
  + Fix main window view menu so that shortcuts can be assigned
    to them.
  + Modified retranslateUi to work correctly with the shortcut
    editor
  + Add option to show toolbar on main window instead of
    text windows
* Sun Mar 28 2010 lars@linux-schulserver.de
- update to 2.6:
  + Fixed an issue causing data loss when closing the main window,
    because open sub-windows were not properly queried for unsaved
    changes.
  + Refactored the module unlocking GUI to provide more info on
    failures and made opening a locked module also initiate the
    unlocking procedure.
  + Fixed a bug that some display/filter settings were not applied
    on startup
  + Add tabbed window arrangement mode
  + Fix problems with manual arrangement mode
  + Implemented a menu item and tool button for opening installed works
  + Refactored a couple of other dialogs to use the new bookshelf model.
    This means they now also have search and grouping fields.
  + Refactored search dialog module chooser dialog
- removed all patches
* Sun Dec 20 2009 lars@linux-schulserver.de
- update to 2.5:
  + improvements to the subwindow arrangement algorithms
  ++ many bugfixes
  ++ new window arrangement modes "Tile" and "Auto Tile"
  + new module selection header in the text windows
  + tons of bugfixes
  + many improvements to the windows port
  + improved debug mode of the application
  + improvements to build system
  + translation updates
  + Christmas splash screen and display template
* Sun Dec 13 2009 lars@linux-schulserver.de
- update to 2.4:
  + many, many bugfixes
  + Improved search dialog
  + Added "get list of install sources from server" functionality
  + BibleTime can now open TEI modules
  + Added new feature called "Change location". It is a shortcut
    (Ctrl-L) that changes the focus to the toolbar field for the
    bible reference or book location.
    This is like the Ctrl-L feature of FireFox.
  + Add shortcut page to config settings dialog
- fix build for fedora
* Thu Jul 23 2009 lars@linux-schulserver.de
- update to 2.0.1:
  + Completed the port to QT. KDE is no longer required.
  + Use default browser instead of just konqueror or firefox.
  + Use docking windows instead of splitters for the left
    side windows.
  + Add Czech translation
  + Add Hungarian Handbook translation
  + Fix drag/drop onto the display window
  + Fix clicking of links in the Mag Window
  + Fix problem causing Mag window to update when it should not
- obsolete bibletime-i18n and bibletime-devel
* Thu Jul 23 2009 lars@linux-schulserver.de
- update to 1.7:
  + tons of bugfixes
  + Port to KDE4/QT4, reduced KDE dependency to a minimum
  + Command line options have changed (--help is out of date)
  + Configuration files have been moved to ~/.bibletime/
  + i18n of UI strings is now handled by QT
  + Massive code cleanups and internal refactoring
  + New bookshelf manager
  + New external communications interface DBUS (instead of DCOP)
  + many Bookshelf improvements
  + Corrections and enhancements to session management
  + Search dialog now has a history for the modules to search in
* Thu Jul 23 2009 lars@linux-schulserver.de
- added virtual provides: sword-frontend
* Mon Dec 15 2008 lars@linux-schulserver.de
- fix gcc 4.3.2 issues
  (bibletime-1.6.5.1-stringcompare.patch)
* Thu Jun 12 2008 lars@linux-schulserver.de
- added
  Recommends:     sword-bible
  Recommends:     sword-commentary
* Mon Jun  9 2008 lars@linux-schulserver.de
- update to 1.6.5.1:
  + bugfix release to build with current gcc
* Mon May 19 2008 lars@linux-schulserver.de
- fix rpm groups
* Sun Dec 23 2007 lars@linux-schulserver.de
- initial version 1.6.5
